@@ -9,13 +9,15 @@
 # and retrieve values dynamically, helping with performance and scalability.
 # Returns complete HTTP response object.
 report <- function(connection, report_id, verbose=FALSE){
-  response <- httr::GET(url = paste0(connection@base_url, '/reports/', report_id),
+  response <- httr::GET(url = paste0(connection@base_url, '/api/v2/reports/', report_id),
                         add_headers('X-MSTR-AuthToken' = connection@auth_token,
                                     'X-MSTR-ProjectID' = connection@project_id),
                         set_cookies(connection@cookies))
   if(verbose){
     print(response$url)
   }
+  error_msg = "Error getting report definition. Check report ID."
+  response_handler(response, error_msg)
   return(response)
 }
 
@@ -23,7 +25,7 @@ report <- function(connection, report_id, verbose=FALSE){
 # This in-memory report instance can be used by other requests.
 # Returns complete HTTP response object.
 report_instance <- function(connection, report_id, body=NULL, offset=0, limit=1000, verbose=FALSE){
-  response <- httr::POST(url = paste0(connection@base_url, '/reports/', report_id, '/instances'),
+  response <- httr::POST(url = paste0(connection@base_url, '/api/v2/reports/', report_id, '/instances'),
                          add_headers('X-MSTR-AuthToken' = connection@auth_token,
                                      'X-MSTR-ProjectID' = connection@project_id),
                          body = body,
@@ -34,14 +36,16 @@ report_instance <- function(connection, report_id, body=NULL, offset=0, limit=10
   if(verbose){
     print(response$url)
   }
+  error_msg <- "Error getting report contents."
+  response_handler(response, error_msg)
   return(response)
 }
 
 # Get the results of a previously created report instance, using the in-memory report instance
-# created by a POST /reports/{reportId}/instances request.
+# created by a POST /v2/reports/{reportId}/instances request.
 # Returns complete HTTP response object.
 report_instance_id <- function(connection, report_id, instance_id, offset=0, limit=1000, verbose=FALSE){
-  response <- httr::GET(url = paste0(connection@base_url, '/reports/', report_id, '/instances/', instance_id),
+  response <- httr::GET(url = paste0(connection@base_url, '/api/v2/reports/', report_id, '/instances/', instance_id),
                         add_headers('X-MSTR-AuthToken' = connection@auth_token,
                                     'X-MSTR-ProjectID' = connection@project_id),
                         query=list(offset = format(offset, scientific=FALSE, trim=TRUE),
@@ -50,6 +54,8 @@ report_instance_id <- function(connection, report_id, instance_id, offset=0, lim
   if(verbose){
     print(response$url)
   }
+  error_msg = sprintf("Error fetching report chunk with limit: %d and offset: %d.", limit, offset)
+  response_handler(response, error_msg)
   return(response)
 }
 
@@ -57,7 +63,7 @@ report_instance_id <- function(connection, report_id, instance_id, offset=0, lim
 # Get elements of a specific attribute of a specific report.
 # Returns complette HTTP response object.
 report_elements <- function(connection, report_id, attribute_id, offset=0, limit=25000, verbose=FALSE) {
-  response <- httr::GET(url = paste0(connection@base_url, '/reports/', report_id, '/attributes/', attribute_id, '/elements'),
+  response <- httr::GET(url = paste0(connection@base_url, '/api/reports/', report_id, '/attributes/', attribute_id, '/elements'),
                         add_headers('X-MSTR-AuthToken' = connection@auth_token,
                                     'X-MSTR-ProjectID' = connection@project_id),
                         query=list(offset = format(offset, scientific=FALSE, trim=TRUE),
@@ -66,5 +72,7 @@ report_elements <- function(connection, report_id, attribute_id, offset=0, limit
   if(verbose){
     print(response$url)
   }
-  response
+  error_msg = "Error loading attribute elements."
+  response_handler(response, error_msg)
+  return(response)
 }
